import { SemVer } from 'semver';
export declare namespace StructureV1 {
    interface iStructureJSON {
        slides: {
            [key: string]: iSlides;
        };
        chapters: {
            [key: string]: iChapter;
        };
        storyboard: string[];
        start?: iStart;
    }
    interface iSlides {
        name: string;
        template: string;
        subslides?: string[];
    }
    interface iChapter {
        name: string;
        content: string[];
    }
}
export interface iStart {
    chapter?: string;
    slide?: string;
}
export declare namespace StructureV2 {
    interface iStructureJSON {
        structureFileVersion: number;
        slides: Record<string, iSlides>;
        chapters: Record<string, iChapter>;
        storyboard: (string | iStoryboardItem)[];
        archivedSlides: {
            slide: string;
            chapter: string | undefined;
        }[];
        start?: iStart;
    }
    interface iSlides {
        name: string;
        template: string;
    }
    interface iChapter {
        name: string;
        content: (string | iChapterContentItem)[];
    }
    interface iStoryboardItem {
        chapter: string;
        hidden?: boolean;
    }
    interface iChapterContentItem extends iSlideItem {
        subslides?: (string | iSlideItem)[];
    }
    interface iSlideItem {
        slide: string;
        hidden?: boolean;
    }
}
export declare type iStructureJSON = StructureV1.iStructureJSON | StructureV2.iStructureJSON;
export declare namespace StructureApi {
    interface SystemSettingsSlideFragment {
        path: {
            slides: string;
            slide: {
                thumbnail: string;
                screenshot?: string;
            };
        };
    }
    enum SlideType {
        Visible = "visible",
        Hidden = "hidden",
        Archived = "archived"
    }
    enum ChapterType {
        Visible = "visible",
        Hidden = "hidden",
        Archived = "archived"
    }
    interface SlideData {
        id: string;
        name: string;
        chapter: ChapterNestedData | undefined;
        type: SlideType;
        thumbnail?: string;
        template?: string;
        custom?: {
            [key: string]: any;
        };
    }
    interface NestedSlideData extends SlideData {
        subslides: SlideData[];
    }
    interface ChapterData {
        id: string;
        name: string;
        type: ChapterType;
        custom?: {
            [key: string]: any;
        };
    }
    interface NestedChapterData {
        id: string;
        name: string;
        type: ChapterType;
        slides: NestedSlideData[];
    }
    type SlideTypes = Partial<Record<SlideType, boolean>>;
    type ChapterTypes = Partial<Record<ChapterType, boolean>>;
    interface StartSlide {
        slide?: string;
        chapter?: string;
    }
    interface ChapterNestedData {
        id: string | undefined;
        name?: string;
        type?: ChapterType;
        storyboardIndex?: number;
        custom?: {
            [key: string]: any;
        };
    }
    interface FlatSlideData extends SlideData {
        isSubslide: boolean;
        parentSlide?: string;
    }
    interface getFlatSlides {
        (structureJson: iStructureJSON, slideTypes?: SlideTypes, systemSettings?: SystemSettingsSlideFragment): FlatSlideData[];
    }
    interface getSlides {
        (structureJson: iStructureJSON, slideTypes?: SlideTypes, systemSettings?: SystemSettingsSlideFragment): NestedSlideData[];
    }
    interface getSlidesAsync {
        (structureJson: iStructureJSON, slideTypes?: SlideTypes, systemSettings?: SystemSettingsSlideFragment, callback?: (arg: (NestedSlideData | SlideData)) => any): Promise<[Record<string, any>] | StructureApi.NestedSlideData[]>;
    }
    interface getVisibleSlides {
        (structureJson: iStructureJSON, systemSettings?: SystemSettingsSlideFragment): NestedSlideData[];
    }
    interface getHiddenSlides {
        (structureJson: iStructureJSON, systemSettings?: SystemSettingsSlideFragment): NestedSlideData[];
    }
    interface getFlatHiddenSlides {
        (structureJson: iStructureJSON, systemSettings?: SystemSettingsSlideFragment): FlatSlideData[];
    }
    interface getArchivedSlides {
        (structureJson: iStructureJSON, systemSettings?: SystemSettingsSlideFragment): NestedSlideData[];
    }
    interface getSlide {
        (structureJson: iStructureJSON, slideId: string, systemSettings?: SystemSettingsSlideFragment): NestedSlideData | undefined;
    }
    interface getFlatSlide {
        (structureJson: iStructureJSON, slideId: string, systemSettings?: SystemSettingsSlideFragment): FlatSlideData | undefined;
    }
    interface getFlatVisibleSlides {
        (structureJson: iStructureJSON, systemSettings?: SystemSettingsSlideFragment): FlatSlideData[];
    }
    interface getChapters {
        (structureJson: iStructureJSON, chapterTypes?: ChapterTypes): ChapterData[];
    }
    interface getHiddenChapters {
        (structureJson: iStructureJSON, chapterTypes?: ChapterTypes): ChapterData[];
    }
    interface getVisibleChapters {
        (structureJson: iStructureJSON, chapterTypes?: ChapterTypes): ChapterData[];
    }
    interface getChapter {
        (structureJson: iStructureJSON, chapterId: string): ChapterData;
    }
    interface getChapterSlides {
        (structureJson: iStructureJSON, chapterId: string, slideTypes?: SlideTypes, systemSettings?: SystemSettingsSlideFragment): NestedSlideData[];
    }
    interface getFlatChapterSlides {
        (structureJson: iStructureJSON, chapterId: string, slideTypes?: SlideTypes, systemSettings?: SystemSettingsSlideFragment): FlatSlideData[];
    }
    interface getSlideSubslides {
        (structureJson: iStructureJSON, slideId: string, slideTypes?: SlideTypes, systemSettings?: SystemSettingsSlideFragment): SlideData[];
    }
    interface getStartSlide {
        (structureJson: iStructureJSON, systemSettings?: SystemSettingsSlideFragment): StartSlide | undefined;
    }
    interface getStoryboard {
        (structureJson: iStructureJSON, chapterTypes?: ChapterTypes, systemSettings?: SystemSettingsSlideFragment): NestedChapterData[];
    }
    interface makeStructure {
        (nestedSlidesData: NestedSlideData[], targetStructureVersion: number): iStructureJSON;
    }
    interface convertToStructureV2 {
        (structureJson: iStructureJSON): StructureV2.iStructureJSON;
    }
    interface getStructureFileVersion {
        (structureJson: iStructureJSON): number;
    }
    interface supportsStructureV2 {
        (version: string | SemVer): boolean;
    }
}
